@@ -3,12 +3,12 @@
 """
 Created on Sat Oct 24 12:36:48 2020
 
-@author: martin
+@author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
 __all__ = ['unitsNetwork']
-__version__ = '0.1.0'
-__release__ = 20220524
+__version__ = '0.1.2'
+__release__ = 20220826
 
 from ._dictionaries import SI, SI_order, OGF, OGF_order, DATA, DATA_order, dictionary, StandardAirDensity, StandadEarthGravity
 
@@ -412,8 +412,17 @@ def _loadNetwork():
     network.addEdge(conversion(network.getNode('gill'), network.getNode('fuild ounce'), lambda v: v*5))
     network.addEdge(conversion(network.getNode('pint'), network.getNode('gill'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('quart'), network.getNode('pint'), lambda v: v*2))
-    network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('quart'), lambda v: v*4))
+    network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('fuild ounce'), lambda v: v*128))
+    network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('quart'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('cubic inch'), lambda v: v*231))
+    
+    network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('quartUK'), lambda v: v*4))
+    network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('fuild ounce UK'), lambda v: v*160))
+    network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('litre'), lambda v: v*4.54609))
+    network.addEdge(conversion(network.getNode('gillUK'), network.getNode('fuild ounce UK'), lambda v: v*5))
+    network.addEdge(conversion(network.getNode('pintUK'), network.getNode('gillUK'), lambda v: v*4))
+    network.addEdge(conversion(network.getNode('quartUK'), network.getNode('pintUK'), lambda v: v*2))
+    
     network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('liter'), lambda v: v* 4.54609))
     network.addEdge(conversion(network.getNode('cubic foot'), network.getNode('cubic meter'), lambda v: v*(3048**3)/(10000**3)))
     network.addEdge(conversion(network.getNode('standard cubic foot'), network.getNode('standard cubic meter'), lambda v: v*(3048**3)/(10000**3)))
@@ -568,6 +577,38 @@ def _create_speed():
     dictionary['speed'] = tuple(set(speed))
 
 
+def _create_productivityIndex():
+    # volume / time / pressure
+    productivityIndex = list(dictionary['productivityIndex']) if 'productivityIndex' in dictionary else []
+    for volume in dictionary['volume']:
+        for time in dictionary['time']:
+            for pressure in dictionary['pressure']:
+                productivityIndex.append(volume+'/'+time+'/'+pressure)
+    dictionary['productivityIndex'] = tuple(set(productivityIndex))
+
+
+def _create_pressureGradient():
+    # pressure / length
+    pressureGradient = list(dictionary['pressureGradient']) if 'pressureGradient' in dictionary else []
+    for pressure in dictionary['pressure']:
+        for length in dictionary['length']:
+            pressureGradient.append(pressure+'/'+length)
+    dictionary['pressureGradient'] = tuple(set(pressureGradient))
+    
+
+def _create_acceleration():
+    # length / time / time
+    acceleration = list(dictionary['acceleration']) if 'acceleration' in dictionary else []
+    for length in dictionary['length']:
+        for time1 in dictionary['time']:
+            for time2 in dictionary['time']:
+                if time1 == time2:
+                    acceleration.append(length+'/'+time1+'2')
+                else:
+                    acceleration.append(length+'/'+time1+'/'+time2)
+    dictionary['acceleration'] = tuple(set(acceleration))
+
+
 # load the network into an instance of the grath database
 unitsNetwork = _loadNetwork()
 
@@ -576,6 +617,9 @@ _create_rates()
 _create_volumeRatio()
 _create_density()
 _create_speed()
+_create_productivityIndex()
+_create_pressureGradient()
+
 
 def network2Frame():
     network=unitsNetwork
